==> owncloud-8.2.2p3.tgz: owncloud/apps/files_sharing/l10n/it.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "La condivisione tra server non è abilitata su questo server",
    "The mountpoint name contains invalid characters." : "Il nome del punto di mount contiene caratteri non validi.",
    "Invalid or untrusted SSL certificate" : "Certificato SSL non valido o non attendibile",
    "Could not authenticate to remote share, password might be wrong" : "Impossibile autenticarsi sulla condivisione remota, la password potrebbe essere errata",
    "Storage not valid" : "Archiviazione non valida",
    "Couldn't add remote share" : "Impossibile aggiungere la condivisione remota",
    "Shared with you" : "Condivisi con te",
    "Shared with others" : "Condivisi con altri",
    "Shared by link" : "Condivisi tramite collegamento",
    "Nothing shared with you yet" : "Non è stato condiviso ancora niente con te",
    "Files and folders others share with you will show up here" : "I file e le cartelle che altri condividono con te saranno mostrati qui",
    "Nothing shared yet" : "Ancora nessuna condivisione",
    "Files and folders you share will show up here" : "I file e le cartelle che condividi saranno mostrati qui",
    "No shared links" : "Nessun collegamento condiviso",
    "Files and folders you share by link will show up here" : "I file e le cartelle che condividi tramite collegamento saranno mostrati qui",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vuoi aggiungere la condivisione remota {name} da {owner}@{remote}?",
    "Remote share" : "Condivisione remota",
    "Remote share password" : "Password della condivisione remota",
    "Cancel" : "Annulla",
    "Add remote share" : "Aggiungi condivisione remota",
    "You can upload into this folder" : "Puoi caricare in questa cartella",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nessuna installazione di ownCloud (7 o superiore) trovata su {remote}",
    "Invalid ownCloud url" : "URL di ownCloud non valido",
    "Shared by" : "Condiviso da",
    "Sharing" : "Condivisione",
    "A file or folder has been <strong>shared</strong>" : "Un file o una cartella è stato <strong>condiviso</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Un file o una cartella è stato condiviso da <strong>un altro server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Un file condiviso pubblicamente o una cartella è stato <strong>scaricato</strong>",
    "You received a new remote share %2$s from %1$s" : "Hai ricevuto una nuova condivisione remota %2$s da %1$s",
    "You received a new remote share from %s" : "Hai ricevuto una nuova condivisione remota da %s",
    "%1$s accepted remote share %2$s" : "%1$s ha accettato la condivisione remota %2$s",
    "%1$s declined remote share %2$s" : "%1$s ha rifiutato la condivisione remota %2$s",
    "%1$s unshared %2$s from you" : "%1$s ha rimosso la condivisione %2$s con te",
    "Public shared folder %1$s was downloaded" : "La cartella condivisa pubblicamente %1$s è stata scaricata",
    "Public shared file %1$s was downloaded" : "Il file condiviso pubblicamente %1$s è stato scaricato",
    "You shared %1$s with %2$s" : "Hai condiviso %1$s con %2$s",
    "You shared %1$s with group %2$s" : "Hai condiviso %1$s con il gruppo %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s ha condiviso %1$s con %3$s",
    "%2$s shared %1$s with group %3$s" : "%2$s ha condiviso %1$s con il gruppo %3$s",
    "%2$s shared %1$s via link" : "%2$s ha condiviso %1$s tramite collegamento",
    "%2$s shared %1$s with you" : "%2$s ha condiviso %1$s con te",
    "You shared %1$s via link" : "Hai condiviso %1$s tramite collegamento",
    "Downloaded via public link" : "Scaricata tramite collegamento pubblico",
    "Shared with %2$s" : "Condivisa con %2$s",
    "Shared with group %2$s" : "Condivisa con il gruppo %2$s",
    "Shared with %3$s by %2$s" : "Condivisa con %3$s da %2$s",
    "Shared with group %3$s by %2$s" : "Condivisa con il gruppo %3$s da %2$s",
    "Shared via link by %2$s" : "Condivisa tramite collegamento da %2$s",
    "Shared by %2$s" : "Condivisa da %2$s",
    "Shared via public link" : "Condivisa tramite collegamento pubblico",
    "Shares" : "Condivisioni",
    "You received %2$s as a remote share from %1$s" : "Hai ricevuto %2$s come condivisione remota da %1$s",
    "Accept" : "Accetta",
    "Decline" : "Rifiuta",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Condividi con me attraverso il mio ID di cloud federata #ownCloud, vedi %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Condividi con me attraverso il mio ID di cloud federata #ownCloud",
    "This share is password-protected" : "Questa condivisione è protetta da password",
    "The password is wrong. Try again." : "La password è errata. Prova ancora.",
    "Password" : "Password",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Name" : "Nome",
    "Share time" : "Tempo di condivisione",
    "Sorry, this link doesn’t seem to work anymore." : "Spiacenti, questo collegamento sembra non essere più attivo.",
    "Reasons might be:" : "I motivi potrebbero essere:",
    "the item was removed" : "l'elemento è stato rimosso",
    "the link expired" : "il collegamento è scaduto",
    "sharing is disabled" : "la condivisione è disabilitata",
    "For more info, please ask the person who sent this link." : "Per ulteriori informazioni, chiedi alla persona che ti ha inviato il collegamento.",
    "Add to your ownCloud" : "Aggiungi al tuo ownCloud",
    "Download" : "Scarica",
    "Download %s" : "Scarica %s",
    "Direct link" : "Collegamento diretto",
    "Federated Cloud Sharing" : "Condivisione cloud federata",
    "Open documentation" : "Apri la documentazione",
    "Allow users on this server to send shares to other servers" : "Consenti agli utenti su questo server di inviare condivisioni ad altri server",
    "Allow users on this server to receive shares from other servers" : "Consenti agli utenti su questo server di ricevere condivisioni da altri server",
    "Federated Cloud" : "Cloud federata",
    "Your Federated Cloud ID:" : "Il tuo ID di cloud federata:",
    "Share it:" : "Condividilo:",
    "Add to your website" : "Aggiungilo al tuo sito web",
    "Share with me via ownCloud" : "Condividi con me tramite ownCloud",
    "HTML Code:" : "Codice HTML:"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.3.tgz: owncloud/apps/files_sharing/l10n/it.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "La condivisione tra server non è abilitata su questo server",
    "The mountpoint name contains invalid characters." : "Il nome del punto di mount contiene caratteri non validi.",
    "Not allowed to create a federated share with the same user server" : "Non è consentito creare una condivisione federata con lo stesso server dell'utente",
    "Invalid or untrusted SSL certificate" : "Certificato SSL non valido o non attendibile",
    "Could not authenticate to remote share, password might be wrong" : "Impossibile autenticarsi sulla condivisione remota, la password potrebbe essere errata",
    "Storage not valid" : "Archiviazione non valida",
    "Couldn't add remote share" : "Impossibile aggiungere la condivisione remota",
    "Shared with you" : "Condivisi con te",
    "Shared with others" : "Condivisi con altri",
    "Shared by link" : "Condivisi tramite collegamento",
    "Federated sharing" : "Condivisione federata",
    "Nothing shared with you yet" : "Non è stato condiviso ancora niente con te",
    "Files and folders others share with you will show up here" : "I file e le cartelle che altri condividono con te saranno mostrati qui",
    "Nothing shared yet" : "Ancora nessuna condivisione",
    "Files and folders you share will show up here" : "I file e le cartelle che condividi saranno mostrati qui",
    "No shared links" : "Nessun collegamento condiviso",
    "Files and folders you share by link will show up here" : "I file e le cartelle che condividi tramite collegamento saranno mostrati qui",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vuoi aggiungere la condivisione remota {name} da {owner}@{remote}?",
    "Remote share" : "Condivisione remota",
    "Remote share password" : "Password della condivisione remota",
    "Cancel" : "Annulla",
    "Add remote share" : "Aggiungi condivisione remota",
    "You can upload into this folder" : "Puoi caricare in questa cartella",
    "No ownCloud installation (7 or higher) found at {remote}" : "Nessuna installazione di ownCloud (7 o superiore) trovata su {remote}",
    "Invalid ownCloud url" : "URL di ownCloud non valido",
    "Shared by" : "Condiviso da",
    "Sharing" : "Condivisione",
    "A file or folder has been <strong>shared</strong>" : "Un file o una cartella è stato <strong>condiviso</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Un file o una cartella è stato condiviso da <strong>un altro server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Un file condiviso pubblicamente o una cartella è stato <strong>scaricato</strong>",
    "You received a new remote share %2$s from %1$s" : "Hai ricevuto una nuova condivisione remota %2$s da %1$s",
    "You received a new remote share from %s" : "Hai ricevuto una nuova condivisione remota da %s",
    "%1$s accepted remote share %2$s" : "%1$s ha accettato la condivisione remota %2$s",
    "%1$s declined remote share %2$s" : "%1$s ha rifiutato la condivisione remota %2$s",
    "%1$s unshared %2$s from you" : "%1$s ha rimosso la condivisione %2$s con te",
    "Public shared folder %1$s was downloaded" : "La cartella condivisa pubblicamente %1$s è stata scaricata",
    "Public shared file %1$s was downloaded" : "Il file condiviso pubblicamente %1$s è stato scaricato",
    "You shared %1$s with %2$s" : "Hai condiviso %1$s con %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s ha condiviso %1$s con %3$s",
    "You removed the share of %2$s for %1$s" : "Hai rimosso la condivisione di %2$s per %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s ha rimosso la condivisione di %3$s per %1$s",
    "You shared %1$s with group %2$s" : "Hai condiviso %1$s con il gruppo %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s ha condiviso %1$s con il gruppo %3$s",
    "You removed the share of group %2$s for %1$s" : "Hai rimosso la condivisione del gruppo %2$s per %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s ha rimosso la condivisione del gruppo %3$s per %1$s",
    "%2$s shared %1$s via link" : "%2$s ha condiviso %1$s tramite collegamento",
    "You shared %1$s via link" : "Hai condiviso %1$s tramite collegamento",
    "You removed the public link for %1$s" : "Hai rimosso il collegamento pubblico per %1$s",
    "%2$s removed the public link for %1$s" : "%2$s ha rimosso il collegamento pubblico per %1$s",
    "Your public link for %1$s expired" : "il tuo collegamento pubblico per %1$s è scaduto",
    "The public link of %2$s for %1$s expired" : "il collegamento pubblico di %2$s per %1$s è scaduto",
    "%2$s shared %1$s with you" : "%2$s ha condiviso %1$s con te",
    "%2$s removed the share for %1$s" : "%2$s ha rimosso la condivisione per %1$s",
    "Downloaded via public link" : "Scaricata tramite collegamento pubblico",
    "Shared with %2$s" : "Condivisa con %2$s",
    "Shared with %3$s by %2$s" : "Condivisa con %3$s da %2$s",
    "Removed share for %2$s" : "Condivisione rimossa per %2$s",
    "%2$s removed share for %3$s" : "%2$s ha rimosso la condivisione per %3$s",
    "Shared with group %2$s" : "Condivisa con il gruppo %2$s",
    "Shared with group %3$s by %2$s" : "Condivisa con il gruppo %3$s da %2$s",
    "Removed share of group %2$s" : "Condivisione rimossa del gruppo %2$s",
    "%2$s removed share of group %3$s" : "%2$s ha rimosso la condivisione del gruppo %3$s",
    "Shared via link by %2$s" : "Condivisa tramite collegamento da %2$s",
    "Shared via public link" : "Condivisa tramite collegamento pubblico",
    "Removed public link" : "Collegamento pubblico rimosso",
    "%2$s removed public link" : "%2$s ha rimosso il collegamento pubblico",
    "Public link expired" : "Collegamento pubblico scaduto",
    "Public link of %2$s expired" : "il collegamento pubblico di %2$s è scaduto",
    "Shared by %2$s" : "Condivisa da %2$s",
    "Shares" : "Condivisioni",
    "You received \"/%2$s\" as a remote share from %1$s" : "Hai ricevuto \"/%2$s\" come condivisione remota da %1$s",
    "Accept" : "Accetta",
    "Decline" : "Rifiuta",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Condividi con me attraverso il mio ID di cloud federata #ownCloud, vedi %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Condividi con me attraverso il mio ID di cloud federata #ownCloud",
    "This share is password-protected" : "Questa condivisione è protetta da password",
    "The password is wrong. Try again." : "La password è errata. Prova ancora.",
    "Password" : "Password",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Name" : "Nome",
    "Share time" : "Tempo di condivisione",
    "Sorry, this link doesn’t seem to work anymore." : "Spiacenti, questo collegamento sembra non essere più attivo.",
    "Reasons might be:" : "I motivi potrebbero essere:",
    "the item was removed" : "l'elemento è stato rimosso",
    "the link expired" : "il collegamento è scaduto",
    "sharing is disabled" : "la condivisione è disabilitata",
    "For more info, please ask the person who sent this link." : "Per ulteriori informazioni, chiedi alla persona che ti ha inviato il collegamento.",
    "Add to your ownCloud" : "Aggiungi al tuo ownCloud",
    "Download" : "Scarica",
    "Download %s" : "Scarica %s",
    "Direct link" : "Collegamento diretto",
    "Federated Cloud Sharing" : "Condivisione cloud federata",
    "Open documentation" : "Apri la documentazione",
    "Allow users on this server to send shares to other servers" : "Consenti agli utenti su questo server di inviare condivisioni ad altri server",
    "Allow users on this server to receive shares from other servers" : "Consenti agli utenti su questo server di ricevere condivisioni da altri server",
    "Federated Cloud" : "Cloud federata",
    "Your Federated Cloud ID:" : "Il tuo ID di cloud federata:",
    "Share it:" : "Condividilo:",
    "Add to your website" : "Aggiungilo al tuo sito web",
    "Share with me via ownCloud" : "Condividi con me tramite ownCloud",
    "HTML Code:" : "Codice HTML:",
    "Public link of %2$s expired" : "il collegamento pubblico di %2$s è scaduto",
    "Public shared file %1$s was downloaded" : "Il file condiviso pubblicamente %1$s è stato scaricato",
    "Public shared folder %1$s was downloaded" : "La cartella condivisa pubblicamente %1$s è stata scaricata",
    "Removed share for %2$s" : "Condivisione rimossa per %2$s",
    "Removed share of group %2$s" : "Condivisione rimossa del gruppo %2$s",
    "Shared by %2$s" : "Condivisa da %2$s",
    "Shared via link by %2$s" : "Condivisa tramite collegamento da %2$s",
    "Shared with group %3$s by %2$s" : "Condivisa con il gruppo %3$s da %2$s",
    "The public link of %2$s for %1$s expired" : "il collegamento pubblico di %2$s per %1$s è scaduto",
    "You removed the public link for %1$s" : "Hai rimosso il collegamento pubblico per %1$s",
    "You removed the share of %2$s for %1$s" : "Hai rimosso la condivisione di %2$s per %1$s",
    "You removed the share of group %2$s for %1$s" : "Hai rimosso la condivisione del gruppo %2$s per %1$s",
    "Your public link for %1$s expired" : "il tuo collegamento pubblico per %1$s è scaduto"
},
"nplurals=2; plural=(n != 1);");
